@@ -137,6 +137,13 @@ def binary_y(arr_y,probability_threshold):
         return((probability_threshold<=arr_y).astype(int))
 
 
+def data_sorter(b_value,quantile_cutoff,quantile_sub):
+    if b_value>quantile_cutoff:
+        return(quantile_sub)
+    else:
+        return(np.abs(b_value))
+
+
 class patient_model():
 
     def __init__(self,period_index,b_values,coefficient_values,link_fn,obs_error,times,first_obs_index,relative_time,period_features,period_extraneous_variables,stationarity_trend_bucket,probability_threshold):
@@ -322,7 +329,7 @@ class patient:
 
 class long_data_set:
 
-    def __init__(self,n=2000,num_measurements=25,collinearity_bucket="low-low",trend_bucket="linear",sampling_bucket="random",sampling_function=None,b_colin=0.13,beta_var=1,b_var=1,time_importance_factor=3,sigma_e=0.05,num_features=2,num_extraneous_variables=0,link_fn="identity",num_piecewise_breaks=0,random_effects=["intercept","time","trend-time"],coefficient_values={},time_breaks=[],probability_threshold=None):
+    def __init__(self,n=2000,num_measurements=25,collinearity_bucket="low-low",trend_bucket="linear",sampling_bucket="random",sampling_function=None,b_colin=0.13,beta_var=1,b_var=1,time_importance_factor=3,sigma_e=0.05,num_features=2,num_extraneous_variables=0,link_fn="identity",num_piecewise_breaks=0,random_effects=["intercept","time","trend-time"],coefficient_values={},time_breaks=[],probability_threshold=None,percentile_sort_cutoff=1,percentile_sub=1):
         self.num_of_patients=n
         self.num_measurements=num_measurements
         self.colinearity_bucket=collinearity_bucket
@@ -336,6 +343,8 @@ class long_data_set:
         self.b_colin=b_colin
         self.sigma_e=sigma_e
         self.sampling_function=sampling_function
+        self.percentile_sort_cutoff=percentile_sort_cutoff
+        self.percentile_sub=percentile_sub
         ###############################
         self.features=[]
         self.probability_threshold=probability_threshold
@@ -375,11 +384,15 @@ class long_data_set:
         b_df=pd.DataFrame(self.b_dict)
         if len(self.random_effects) > 0:
             if "intercept" in self.b_dict:
-                b_df['sort_col']=b_df["intercept"].abs()
+                cut_off=np.quantile(b_df["intercept"],self.percentile_sort_cutoff)
+                sub_value=np.quantile(b_df["intercept"],self.percentile_sub)
+                b_df['sort_col']=b_df["intercept"].apply(lambda v: data_sorter(v,cut_off,sub_value))
             elif "time" in self.b_dict:
-                b_df['sort_col']=b_df["time"].abs()
+                cut_off=np.quantile(b_df["time"],self.percentile_sort_cutoff)
+                b_df['sort_col']=b_df["time"].apply(lambda v: data_sorter(v,cut_off,sub_value))
             elif "trend-time" in self.b_dict:
-                b_df['sort_col']=b_df["trend-time"].abs()
+                cut_off=np.quantile(b_df["trend-time"],self.percentile_sort_cutoff)
+                b_df['sort_col']=b_df["trend-time"].apply(lambda v: data_sorter(v,cut_off,sub_value))
             else:
                 sort_col=b_df.columns.values[0]
                 b_df['sort_col']=b_df[sort_col].abs()
